#!/usr/bin/env python

from platform import system
import logging

import collections

import mraa

if system() == 'Windows':
    from Emulator.TCPClient import TCPClient

_logger = logging.getLogger(__name__)

DAC5578_CHANNEL = collections.namedtuple('DAC5578_CHANNEL', 'A B C D E F G H')._make(range(8))


class DAC5578(object):
    dev = None

    def __init__(self):
        DAC5578.dev = mraa.I2c(0)
        if system() == 'WINDOWS':
            DAC5578.dev.frequency(mraa.I2cMode.I2C_STD)
        else:
            DAC5578.dev.frequency(mraa.I2C_STD)
        DAC5578.dev.address(0x48)
        DAC5578.dev.writeWordReg(0x00, 0xff00)
        if system() == 'Windows':
            self._emulatorClient = TCPClient(44444)

    def set_value(self, channel, value):
        DAC5578.dev.address(0x48)
        # write to DAC input register for channel X and update channel X DAC register
        reg = ((0x3 << 4) | (channel & 0xF))
        DAC5578.dev.writeWordReg(reg, value)
        if system() == 'Windows':
            self._emulatorClient.transmit('req DAC set {} {}'.format(channel, value))
            # _logger.debug('set value {} {}'.format(channel, value))
